pub trait QueueOwnedT: QueueT {
    fn iter<M>(&mut self, mem: M) -> Result<AvailIter<'_, M>, Error>
    where
        M: Deref,
        M::Target: GuestMemory
; fn go_to_previous_position(&mut self); }
Trait to access and manipulate a Virtio queue that’s known to be exclusively accessed by a single execution thread.

Required Methods

Get a consuming iterator over all available descriptor chain heads offered by the driver.

Arguments
  • mem - the GuestMemory object that can be used to access the queue buffers.

Undo the last advancement of the next available index field by decrementing its value by one.

Implementors